'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _graphqlTools = require('graphql-tools');

var _buildTypeAndResolvers = require('./buildTypeAndResolvers');

var _buildTypeAndResolvers2 = _interopRequireDefault(_buildTypeAndResolvers);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const rootType = `
  type Query {
    nope: String
  }

  type Mutation {
    nope: String
  }

  input InputFile {
    name: String!
    type: String!
    size: Int!
    path: String!
  }
`;

class Schema {
  constructor(models) {
    this.models = models;
  }

  buildSchema() {
    const models = this.models.map(v => {
      v.Name = v.Name;
      v.name = v.name || _lodash2.default.camelCase(v.Name);
      v.names = v.names || _lodash2.default.pluralize(v.name);
      return (0, _buildTypeAndResolvers2.default)(v);
    });
    const modelTypes = models.map(v => v.type);
    const modelResolvers = models.map(v => v.resolvers);

    const typeDefs = [rootType, ...modelTypes];
    const resolvers = (0, _lodash.merge)({}, ...modelResolvers);
    //typeDefs.forEach(v => console.log(v))

    return (0, _graphqlTools.makeExecutableSchema)({ typeDefs, resolvers });
  }
}
exports.default = Schema;