'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = buildTypeAndResolvers;

var _lodash = require('lodash');

var _resolver = require('./resolver');

var _resolver2 = _interopRequireDefault(_resolver);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DEFAULT_MODEL = {
  fields: {},
  hooks: {
    beforeCreate() {},
    afterCreate() {},
    beforeUpdate() {},
    afterUpdate() {},
    beforeDelete() {},
    afterDelete() {}
  }
};

function buildTypeAndResolvers(Model) {
  (0, _lodash.defaultsDeep)(Model, DEFAULT_MODEL);
  const { Name, name, names } = Model;

  const fields = (0, _lodash.map)(Model.fields, (value, key) => {
    const type = value.type === 'File' ? 'String' : value.type;
    return `${key}: ${type}`;
  }).join('\n');

  const inputFields = (0, _lodash.map)(Model.fields, (value, key) => {
    const type = value.type === 'File' ? 'InputFile' : value.type;
    return `${key}: ${type}`;
  }).join('\n');

  const type = `
    type ${Name} {
      id: ID
      ${fields}
    }

    type ${Name}Connection {
      nodes: [${Name}]
      totalCount: Int
    }

    extend type Query {
      ${names}(page: Int, perPage: Int, orderBy: String): ${Name}Connection
      ${name}: ${Name}
    }

    extend type Mutation {
      create${Name}(input: Create${Name}Input): ${Name}
      update${Name}(id: ID!, input: Update${Name}Input): ${Name}
      delete${Name}(id: ID!): ${Name}
    }

    input Create${Name}Input {
      ${inputFields}
    }
    input Update${Name}Input {
      ${inputFields}
    }
  `;

  // products(q: String, tags: String, category: String, saved: Int, orderBy: String, page: Int, limit: Int): ProductConn
  // page, perPage, orderBy
  // <ATTR>
  const resolvers = {
    Query: {
      [names]: (0, _resolver2.default)(Model),
      [name]: (0, _resolver2.default)(Model)
    },
    Mutation: {
      [`create${Name}`]: (0, _resolver2.default)(Model),
      [`update${Name}`]: (0, _resolver2.default)(Model),
      [`delete${Name}`]: (0, _resolver2.default)(Model)
    }
  };

  return { type, resolvers };
}